"""
    ICA Rest API

    This API can be used to interact with Illumina Connected Analytics.<br> <h2>Authentication</h2> <p> Authentication to the  API can be done in multiple ways:<br> <ul><li>For the entire API, except for the POST /tokens endpoint: API-key + JWT</li> <li>Only for the POST /tokens endpoint: API-key + Basic Authentication</li></ul> </p> <p> <h4>API-key</h4> API keys are managed within the Illumina portal where you can manage your profile after you have logged on. The API-key has to be provided in the X-API-Key header parameter when executing API calls to ICA. In the background, a JWT will be requested at the IDP of Illumina to create a session. A good practice is to not use the API-key for every API call, but to first generate a JWT and to use that for authentication in subsequent calls.<br> </p> <p> <h4>JWT</h4> To avoid using an API-key for each call, we recommend to request a JWT via the POST /tokens endpoint  using this API-key. The JWT will expire after a pre-configured period specified by a tenant administrator through the IAM console in the Illumina portal. The JWT is the preferred way for authentication.<br>A not yet expired, still valid JWT could be refreshed using the POST /tokens:refresh endpoint.<br>Refreshing the JWT is not possible if the JWT was generated by using an API-key.<br> </p> <p> <h4>Basic Authentication</h4> Basic authentication is only supported by the POST /tokens endpoint for generating a JWT. Use \"Basic base64encoded(emailaddress:password)\" in the \"Authorization\" header parameter for this authentication method. In case having access to multiple tenants using the same email-address, also provide the \"tenant\" request parameter to indicate what tenant you would like to request a JWT for. </p> <p> <h2>Compression</h2> If the API client provides request header 'Accept-Encoding' with value 'gzip', then the API applies GZIP compression on the JSON response. This significantly reduces the size and thus the download time of the response, which results in faster end-to-end API calls. In case of compression, the API also provides response header 'Content-Encoding' with value 'gzip', as indication for the client that decompression is required. </p>   # noqa: E501

    The version of the OpenAPI document: 3
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from libica.openapi.v2.api_client import ApiClient, Endpoint as _Endpoint
from libica.openapi.v2.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from libica.openapi.v2.model.connector import Connector
from libica.openapi.v2.model.connector_list import ConnectorList
from libica.openapi.v2.model.create_connector import CreateConnector
from libica.openapi.v2.model.create_download_rule import CreateDownloadRule
from libica.openapi.v2.model.create_upload_rule import CreateUploadRule
from libica.openapi.v2.model.download_rule import DownloadRule
from libica.openapi.v2.model.download_rule_list import DownloadRuleList
from libica.openapi.v2.model.problem import Problem
from libica.openapi.v2.model.upload_rule import UploadRule
from libica.openapi.v2.model.upload_rule_list import UploadRuleList


class ConnectorApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.cancel_connector_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/connectors/{connectorId}:cancel',
                'operation_id': 'cancel_connector',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'connector_id',
                ],
                'required': [
                    'connector_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'connector_id':
                        (str,),
                },
                'attribute_map': {
                    'connector_id': 'connectorId',
                },
                'location_map': {
                    'connector_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.create_connector_endpoint = _Endpoint(
            settings={
                'response_type': (Connector,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/connectors',
                'operation_id': 'create_connector',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'create_connector',
                ],
                'required': [
                    'create_connector',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'create_connector':
                        (CreateConnector,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'create_connector': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [
                    'application/vnd.illumina.v3+json',
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.create_download_rule_endpoint = _Endpoint(
            settings={
                'response_type': (DownloadRule,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/connectors/{connectorId}/downloadRules',
                'operation_id': 'create_download_rule',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'connector_id',
                    'create_download_rule',
                ],
                'required': [
                    'connector_id',
                    'create_download_rule',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'connector_id':
                        (str,),
                    'create_download_rule':
                        (CreateDownloadRule,),
                },
                'attribute_map': {
                    'connector_id': 'connectorId',
                },
                'location_map': {
                    'connector_id': 'path',
                    'create_download_rule': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [
                    'application/vnd.illumina.v3+json',
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.create_upload_rule_endpoint = _Endpoint(
            settings={
                'response_type': (UploadRule,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/connectors/{connectorId}/uploadRules',
                'operation_id': 'create_upload_rule',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'connector_id',
                    'create_upload_rule',
                ],
                'required': [
                    'connector_id',
                    'create_upload_rule',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'connector_id':
                        (str,),
                    'create_upload_rule':
                        (CreateUploadRule,),
                },
                'attribute_map': {
                    'connector_id': 'connectorId',
                },
                'location_map': {
                    'connector_id': 'path',
                    'create_upload_rule': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [
                    'application/vnd.illumina.v3+json',
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.delete_download_rule_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/connectors/{connectorId}/downloadRules/{downloadRuleId}',
                'operation_id': 'delete_download_rule',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'connector_id',
                    'download_rule_id',
                ],
                'required': [
                    'connector_id',
                    'download_rule_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'connector_id':
                        (str,),
                    'download_rule_id':
                        (str,),
                },
                'attribute_map': {
                    'connector_id': 'connectorId',
                    'download_rule_id': 'downloadRuleId',
                },
                'location_map': {
                    'connector_id': 'path',
                    'download_rule_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.delete_upload_rule_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/connectors/{connectorId}/uploadRules/{uploadRuleId}',
                'operation_id': 'delete_upload_rule',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'connector_id',
                    'upload_rule_id',
                ],
                'required': [
                    'connector_id',
                    'upload_rule_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'connector_id':
                        (str,),
                    'upload_rule_id':
                        (str,),
                },
                'attribute_map': {
                    'connector_id': 'connectorId',
                    'upload_rule_id': 'uploadRuleId',
                },
                'location_map': {
                    'connector_id': 'path',
                    'upload_rule_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.disable_connector_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/connectors/{connectorId}:disable',
                'operation_id': 'disable_connector',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'connector_id',
                ],
                'required': [
                    'connector_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'connector_id':
                        (str,),
                },
                'attribute_map': {
                    'connector_id': 'connectorId',
                },
                'location_map': {
                    'connector_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.enable_connector_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/connectors/{connectorId}:enable',
                'operation_id': 'enable_connector',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'connector_id',
                ],
                'required': [
                    'connector_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'connector_id':
                        (str,),
                },
                'attribute_map': {
                    'connector_id': 'connectorId',
                },
                'location_map': {
                    'connector_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_connector_endpoint = _Endpoint(
            settings={
                'response_type': (Connector,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/connectors/{connectorId}',
                'operation_id': 'get_connector',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'connector_id',
                ],
                'required': [
                    'connector_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'connector_id':
                        (str,),
                },
                'attribute_map': {
                    'connector_id': 'connectorId',
                },
                'location_map': {
                    'connector_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_connectors_endpoint = _Endpoint(
            settings={
                'response_type': (ConnectorList,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/connectors',
                'operation_id': 'get_connectors',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'active_only',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'active_only':
                        (bool,),
                },
                'attribute_map': {
                    'active_only': 'activeOnly',
                },
                'location_map': {
                    'active_only': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_download_rule_endpoint = _Endpoint(
            settings={
                'response_type': (DownloadRule,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/connectors/{connectorId}/downloadRules/{downloadRuleId}',
                'operation_id': 'get_download_rule',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'connector_id',
                    'download_rule_id',
                ],
                'required': [
                    'connector_id',
                    'download_rule_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'connector_id':
                        (str,),
                    'download_rule_id':
                        (str,),
                },
                'attribute_map': {
                    'connector_id': 'connectorId',
                    'download_rule_id': 'downloadRuleId',
                },
                'location_map': {
                    'connector_id': 'path',
                    'download_rule_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_download_rules_endpoint = _Endpoint(
            settings={
                'response_type': (DownloadRuleList,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/connectors/{connectorId}/downloadRules',
                'operation_id': 'get_download_rules',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'connector_id',
                ],
                'required': [
                    'connector_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'connector_id':
                        (str,),
                },
                'attribute_map': {
                    'connector_id': 'connectorId',
                },
                'location_map': {
                    'connector_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_upload_rule_endpoint = _Endpoint(
            settings={
                'response_type': (UploadRule,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/connectors/{connectorId}/uploadRules/{uploadRuleId}',
                'operation_id': 'get_upload_rule',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'connector_id',
                    'upload_rule_id',
                ],
                'required': [
                    'connector_id',
                    'upload_rule_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'connector_id':
                        (str,),
                    'upload_rule_id':
                        (str,),
                },
                'attribute_map': {
                    'connector_id': 'connectorId',
                    'upload_rule_id': 'uploadRuleId',
                },
                'location_map': {
                    'connector_id': 'path',
                    'upload_rule_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_upload_rules_endpoint = _Endpoint(
            settings={
                'response_type': (UploadRuleList,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/connectors/{connectorId}/uploadRules',
                'operation_id': 'get_upload_rules',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'connector_id',
                ],
                'required': [
                    'connector_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'connector_id':
                        (str,),
                },
                'attribute_map': {
                    'connector_id': 'connectorId',
                },
                'location_map': {
                    'connector_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_download_rule_endpoint = _Endpoint(
            settings={
                'response_type': (DownloadRule,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/connectors/{connectorId}/downloadRules/{downloadRuleId}',
                'operation_id': 'update_download_rule',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'connector_id',
                    'download_rule_id',
                    'download_rule',
                    'if_match',
                ],
                'required': [
                    'connector_id',
                    'download_rule_id',
                    'download_rule',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'connector_id':
                        (str,),
                    'download_rule_id':
                        (str,),
                    'download_rule':
                        (DownloadRule,),
                    'if_match':
                        (str,),
                },
                'attribute_map': {
                    'connector_id': 'connectorId',
                    'download_rule_id': 'downloadRuleId',
                    'if_match': 'If-Match',
                },
                'location_map': {
                    'connector_id': 'path',
                    'download_rule_id': 'path',
                    'download_rule': 'body',
                    'if_match': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [
                    'application/vnd.illumina.v3+json',
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.update_upload_rule_endpoint = _Endpoint(
            settings={
                'response_type': (UploadRule,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/connectors/{connectorId}/uploadRules/{uploadRuleId}',
                'operation_id': 'update_upload_rule',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'connector_id',
                    'upload_rule_id',
                    'upload_rule',
                    'if_match',
                ],
                'required': [
                    'connector_id',
                    'upload_rule_id',
                    'upload_rule',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'connector_id':
                        (str,),
                    'upload_rule_id':
                        (str,),
                    'upload_rule':
                        (UploadRule,),
                    'if_match':
                        (str,),
                },
                'attribute_map': {
                    'connector_id': 'connectorId',
                    'upload_rule_id': 'uploadRuleId',
                    'if_match': 'If-Match',
                },
                'location_map': {
                    'connector_id': 'path',
                    'upload_rule_id': 'path',
                    'upload_rule': 'body',
                    'if_match': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [
                    'application/vnd.illumina.v3+json',
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def cancel_connector(
        self,
        connector_id,
        **kwargs
    ):
        """Cancel a connector.  # noqa: E501

        Endpoint for cancelling a connector. This is a non-RESTful endpoint, as the path of this endpoint is not representing a REST resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.cancel_connector(connector_id, async_req=True)
        >>> result = thread.get()

        Args:
            connector_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['connector_id'] = \
            connector_id
        return self.cancel_connector_endpoint.call_with_http_info(**kwargs)

    def create_connector(
        self,
        create_connector,
        **kwargs
    ):
        """Create a connector.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_connector(create_connector, async_req=True)
        >>> result = thread.get()

        Args:
            create_connector (CreateConnector): The connector to create.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Connector
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['create_connector'] = \
            create_connector
        return self.create_connector_endpoint.call_with_http_info(**kwargs)

    def create_download_rule(
        self,
        connector_id,
        create_download_rule,
        **kwargs
    ):
        """Create a download rule.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_download_rule(connector_id, create_download_rule, async_req=True)
        >>> result = thread.get()

        Args:
            connector_id (str):
            create_download_rule (CreateDownloadRule):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            DownloadRule
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['connector_id'] = \
            connector_id
        kwargs['create_download_rule'] = \
            create_download_rule
        return self.create_download_rule_endpoint.call_with_http_info(**kwargs)

    def create_upload_rule(
        self,
        connector_id,
        create_upload_rule,
        **kwargs
    ):
        """Create an upload rule.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_upload_rule(connector_id, create_upload_rule, async_req=True)
        >>> result = thread.get()

        Args:
            connector_id (str):
            create_upload_rule (CreateUploadRule):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            UploadRule
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['connector_id'] = \
            connector_id
        kwargs['create_upload_rule'] = \
            create_upload_rule
        return self.create_upload_rule_endpoint.call_with_http_info(**kwargs)

    def delete_download_rule(
        self,
        connector_id,
        download_rule_id,
        **kwargs
    ):
        """Delete a download rule.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_download_rule(connector_id, download_rule_id, async_req=True)
        >>> result = thread.get()

        Args:
            connector_id (str):
            download_rule_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['connector_id'] = \
            connector_id
        kwargs['download_rule_id'] = \
            download_rule_id
        return self.delete_download_rule_endpoint.call_with_http_info(**kwargs)

    def delete_upload_rule(
        self,
        connector_id,
        upload_rule_id,
        **kwargs
    ):
        """Delete an upload rule.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_upload_rule(connector_id, upload_rule_id, async_req=True)
        >>> result = thread.get()

        Args:
            connector_id (str):
            upload_rule_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['connector_id'] = \
            connector_id
        kwargs['upload_rule_id'] = \
            upload_rule_id
        return self.delete_upload_rule_endpoint.call_with_http_info(**kwargs)

    def disable_connector(
        self,
        connector_id,
        **kwargs
    ):
        """Disable a connector.  # noqa: E501

        Endpoint for disabling a connector. This is a non-RESTful endpoint, as the path of this endpoint is not representing a REST resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.disable_connector(connector_id, async_req=True)
        >>> result = thread.get()

        Args:
            connector_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['connector_id'] = \
            connector_id
        return self.disable_connector_endpoint.call_with_http_info(**kwargs)

    def enable_connector(
        self,
        connector_id,
        **kwargs
    ):
        """Enable a connector.  # noqa: E501

        Endpoint for enabling a connector. This is a non-RESTful endpoint, as the path of this endpoint is not representing a REST resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.enable_connector(connector_id, async_req=True)
        >>> result = thread.get()

        Args:
            connector_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['connector_id'] = \
            connector_id
        return self.enable_connector_endpoint.call_with_http_info(**kwargs)

    def get_connector(
        self,
        connector_id,
        **kwargs
    ):
        """Retrieve a connector.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_connector(connector_id, async_req=True)
        >>> result = thread.get()

        Args:
            connector_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Connector
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['connector_id'] = \
            connector_id
        return self.get_connector_endpoint.call_with_http_info(**kwargs)

    def get_connectors(
        self,
        **kwargs
    ):
        """Retrieve a list of connectors.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_connectors(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            active_only (bool): When true only the active connectors will be returned. When false (default value) all connectors wil be returned.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ConnectorList
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.get_connectors_endpoint.call_with_http_info(**kwargs)

    def get_download_rule(
        self,
        connector_id,
        download_rule_id,
        **kwargs
    ):
        """Retrieve a download rule.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_download_rule(connector_id, download_rule_id, async_req=True)
        >>> result = thread.get()

        Args:
            connector_id (str):
            download_rule_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            DownloadRule
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['connector_id'] = \
            connector_id
        kwargs['download_rule_id'] = \
            download_rule_id
        return self.get_download_rule_endpoint.call_with_http_info(**kwargs)

    def get_download_rules(
        self,
        connector_id,
        **kwargs
    ):
        """Retrieve a list of download rules.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_download_rules(connector_id, async_req=True)
        >>> result = thread.get()

        Args:
            connector_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            DownloadRuleList
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['connector_id'] = \
            connector_id
        return self.get_download_rules_endpoint.call_with_http_info(**kwargs)

    def get_upload_rule(
        self,
        connector_id,
        upload_rule_id,
        **kwargs
    ):
        """Retrieve an upload rule.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_upload_rule(connector_id, upload_rule_id, async_req=True)
        >>> result = thread.get()

        Args:
            connector_id (str):
            upload_rule_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            UploadRule
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['connector_id'] = \
            connector_id
        kwargs['upload_rule_id'] = \
            upload_rule_id
        return self.get_upload_rule_endpoint.call_with_http_info(**kwargs)

    def get_upload_rules(
        self,
        connector_id,
        **kwargs
    ):
        """Retrieve a list of upload rules.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_upload_rules(connector_id, async_req=True)
        >>> result = thread.get()

        Args:
            connector_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            UploadRuleList
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['connector_id'] = \
            connector_id
        return self.get_upload_rules_endpoint.call_with_http_info(**kwargs)

    def update_download_rule(
        self,
        connector_id,
        download_rule_id,
        download_rule,
        **kwargs
    ):
        """Update a download rule.  # noqa: E501

        Fields which can be updated:  - code  - active  - description  - sequence  - formatCode  - projectName  - targetLocalFolder  - protocol  - fileNameExpression  - disableHashing  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_download_rule(connector_id, download_rule_id, download_rule, async_req=True)
        >>> result = thread.get()

        Args:
            connector_id (str):
            download_rule_id (str):
            download_rule (DownloadRule):

        Keyword Args:
            if_match (str): Optional header parameter to enable conflict exposure. If the client provides this header, then it must contains the client's most recent value of the 'ETag' response header, and the server will respond with a 409 code if it detects a conflict. If the client does not provide this header, then the server will not do a conflict check, which means that as a client you can override the resource even when the server has a more recent version.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            DownloadRule
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['connector_id'] = \
            connector_id
        kwargs['download_rule_id'] = \
            download_rule_id
        kwargs['download_rule'] = \
            download_rule
        return self.update_download_rule_endpoint.call_with_http_info(**kwargs)

    def update_upload_rule(
        self,
        connector_id,
        upload_rule_id,
        upload_rule,
        **kwargs
    ):
        """Update an upload rule.  # noqa: E501

        Fields which can be updated:  - code  - active  - description  - localFolder  - filePattern  - dataFormat   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_upload_rule(connector_id, upload_rule_id, upload_rule, async_req=True)
        >>> result = thread.get()

        Args:
            connector_id (str):
            upload_rule_id (str):
            upload_rule (UploadRule):

        Keyword Args:
            if_match (str): Optional header parameter to enable conflict exposure. If the client provides this header, then it must contains the client's most recent value of the 'ETag' response header, and the server will respond with a 409 code if it detects a conflict. If the client does not provide this header, then the server will not do a conflict check, which means that as a client you can override the resource even when the server has a more recent version.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            UploadRule
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['connector_id'] = \
            connector_id
        kwargs['upload_rule_id'] = \
            upload_rule_id
        kwargs['upload_rule'] = \
            upload_rule
        return self.update_upload_rule_endpoint.call_with_http_info(**kwargs)




# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class AWSS3ObjectStoreSetting(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bucket_name': 'str',
        'key_prefix': 'str',
        'server_side_encryption_algorithm': 'str',
        'server_side_encryption_key': 'str'
    }

    attribute_map = {
        'bucket_name': 'bucketName',
        'key_prefix': 'keyPrefix',
        'server_side_encryption_algorithm': 'serverSideEncryptionAlgorithm',
        'server_side_encryption_key': 'serverSideEncryptionKey'
    }

    def __init__(self, bucket_name=None, key_prefix=None, server_side_encryption_algorithm=None, server_side_encryption_key=None, local_vars_configuration=None):  # noqa: E501
        """AWSS3ObjectStoreSetting - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bucket_name = None
        self._key_prefix = None
        self._server_side_encryption_algorithm = None
        self._server_side_encryption_key = None
        self.discriminator = None

        self.bucket_name = bucket_name
        if key_prefix is not None:
            self.key_prefix = key_prefix
        if server_side_encryption_algorithm is not None:
            self.server_side_encryption_algorithm = server_side_encryption_algorithm
        if server_side_encryption_key is not None:
            self.server_side_encryption_key = server_side_encryption_key

    @property
    def bucket_name(self):
        """Gets the bucket_name of this AWSS3ObjectStoreSetting.  # noqa: E501

        The bucket name  # noqa: E501

        :return: The bucket_name of this AWSS3ObjectStoreSetting.  # noqa: E501
        :rtype: str
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        """Sets the bucket_name of this AWSS3ObjectStoreSetting.

        The bucket name  # noqa: E501

        :param bucket_name: The bucket_name of this AWSS3ObjectStoreSetting.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and bucket_name is None:  # noqa: E501
            raise ValueError("Invalid value for `bucket_name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                bucket_name is not None and len(bucket_name) > 63):
            raise ValueError("Invalid value for `bucket_name`, length must be less than or equal to `63`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                bucket_name is not None and len(bucket_name) < 3):
            raise ValueError("Invalid value for `bucket_name`, length must be greater than or equal to `3`")  # noqa: E501

        self._bucket_name = bucket_name

    @property
    def key_prefix(self):
        """Gets the key_prefix of this AWSS3ObjectStoreSetting.  # noqa: E501

        Key prefix within the bucket for GDS to operate within. Volumes may only be created within this prefix and the given credentials need only authorize  access here. If not set, default is to allow operation on the full bucket. No leading slash, and must end with a trailing slash.  # noqa: E501

        :return: The key_prefix of this AWSS3ObjectStoreSetting.  # noqa: E501
        :rtype: str
        """
        return self._key_prefix

    @key_prefix.setter
    def key_prefix(self, key_prefix):
        """Sets the key_prefix of this AWSS3ObjectStoreSetting.

        Key prefix within the bucket for GDS to operate within. Volumes may only be created within this prefix and the given credentials need only authorize  access here. If not set, default is to allow operation on the full bucket. No leading slash, and must end with a trailing slash.  # noqa: E501

        :param key_prefix: The key_prefix of this AWSS3ObjectStoreSetting.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                key_prefix is not None and not re.search(r'^[^\/].*$', key_prefix)):  # noqa: E501
            raise ValueError(r"Invalid value for `key_prefix`, must be a follow pattern or equal to `/^[^\/].*$/`")  # noqa: E501

        self._key_prefix = key_prefix

    @property
    def server_side_encryption_algorithm(self):
        """Gets the server_side_encryption_algorithm of this AWSS3ObjectStoreSetting.  # noqa: E501

        Used to specify the type of server-side encryption (SSE) to be used on the object provider.  This value is used to determine the Amazon S3 header \"x-amz-server-side-encryption\" value.  For example, specify \"AES256\" for SSE-S3, or \"AWS:KMS\" for SSE-KMS.  By default if none is specified, \"AES256\" will be used.  # noqa: E501

        :return: The server_side_encryption_algorithm of this AWSS3ObjectStoreSetting.  # noqa: E501
        :rtype: str
        """
        return self._server_side_encryption_algorithm

    @server_side_encryption_algorithm.setter
    def server_side_encryption_algorithm(self, server_side_encryption_algorithm):
        """Sets the server_side_encryption_algorithm of this AWSS3ObjectStoreSetting.

        Used to specify the type of server-side encryption (SSE) to be used on the object provider.  This value is used to determine the Amazon S3 header \"x-amz-server-side-encryption\" value.  For example, specify \"AES256\" for SSE-S3, or \"AWS:KMS\" for SSE-KMS.  By default if none is specified, \"AES256\" will be used.  # noqa: E501

        :param server_side_encryption_algorithm: The server_side_encryption_algorithm of this AWSS3ObjectStoreSetting.  # noqa: E501
        :type: str
        """

        self._server_side_encryption_algorithm = server_side_encryption_algorithm

    @property
    def server_side_encryption_key(self):
        """Gets the server_side_encryption_key of this AWSS3ObjectStoreSetting.  # noqa: E501

        Used to specify the serve-side encryption key that might be associated with the specified server-side encryption algorithm  This value can be the AWS KMS arn key, to be used for the Amazon S3 header \"x-amz-server-side-encryption-aws-kms-key-id\" value  Value will be ignored if encryption is \"AES256\"  # noqa: E501

        :return: The server_side_encryption_key of this AWSS3ObjectStoreSetting.  # noqa: E501
        :rtype: str
        """
        return self._server_side_encryption_key

    @server_side_encryption_key.setter
    def server_side_encryption_key(self, server_side_encryption_key):
        """Sets the server_side_encryption_key of this AWSS3ObjectStoreSetting.

        Used to specify the serve-side encryption key that might be associated with the specified server-side encryption algorithm  This value can be the AWS KMS arn key, to be used for the Amazon S3 header \"x-amz-server-side-encryption-aws-kms-key-id\" value  Value will be ignored if encryption is \"AES256\"  # noqa: E501

        :param server_side_encryption_key: The server_side_encryption_key of this AWSS3ObjectStoreSetting.  # noqa: E501
        :type: str
        """

        self._server_side_encryption_key = server_side_encryption_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AWSS3ObjectStoreSetting):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AWSS3ObjectStoreSetting):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class JobOperationParameters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'folder_copy': 'FolderCopyOperationParameters',
        'folder_delete': 'FolderDeleteOperationParameters',
        'volume_migration': 'VolumeMigrationOperationParameters',
        'file_copy': 'FileCopyOperationParameters',
        'bulk_metadata_update': 'BulkMetadataUpdateOperationParameters',
        'file_move': 'FileMoveOperationParameters',
        'folder_move': 'FolderMoveOperationParameters'
    }

    attribute_map = {
        'folder_copy': 'folderCopy',
        'folder_delete': 'folderDelete',
        'volume_migration': 'volumeMigration',
        'file_copy': 'fileCopy',
        'bulk_metadata_update': 'bulkMetadataUpdate',
        'file_move': 'fileMove',
        'folder_move': 'folderMove'
    }

    def __init__(self, folder_copy=None, folder_delete=None, volume_migration=None, file_copy=None, bulk_metadata_update=None, file_move=None, folder_move=None, local_vars_configuration=None):  # noqa: E501
        """JobOperationParameters - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._folder_copy = None
        self._folder_delete = None
        self._volume_migration = None
        self._file_copy = None
        self._bulk_metadata_update = None
        self._file_move = None
        self._folder_move = None
        self.discriminator = None

        if folder_copy is not None:
            self.folder_copy = folder_copy
        if folder_delete is not None:
            self.folder_delete = folder_delete
        if volume_migration is not None:
            self.volume_migration = volume_migration
        if file_copy is not None:
            self.file_copy = file_copy
        if bulk_metadata_update is not None:
            self.bulk_metadata_update = bulk_metadata_update
        if file_move is not None:
            self.file_move = file_move
        if folder_move is not None:
            self.folder_move = folder_move

    @property
    def folder_copy(self):
        """Gets the folder_copy of this JobOperationParameters.  # noqa: E501


        :return: The folder_copy of this JobOperationParameters.  # noqa: E501
        :rtype: FolderCopyOperationParameters
        """
        return self._folder_copy

    @folder_copy.setter
    def folder_copy(self, folder_copy):
        """Sets the folder_copy of this JobOperationParameters.


        :param folder_copy: The folder_copy of this JobOperationParameters.  # noqa: E501
        :type: FolderCopyOperationParameters
        """

        self._folder_copy = folder_copy

    @property
    def folder_delete(self):
        """Gets the folder_delete of this JobOperationParameters.  # noqa: E501


        :return: The folder_delete of this JobOperationParameters.  # noqa: E501
        :rtype: FolderDeleteOperationParameters
        """
        return self._folder_delete

    @folder_delete.setter
    def folder_delete(self, folder_delete):
        """Sets the folder_delete of this JobOperationParameters.


        :param folder_delete: The folder_delete of this JobOperationParameters.  # noqa: E501
        :type: FolderDeleteOperationParameters
        """

        self._folder_delete = folder_delete

    @property
    def volume_migration(self):
        """Gets the volume_migration of this JobOperationParameters.  # noqa: E501


        :return: The volume_migration of this JobOperationParameters.  # noqa: E501
        :rtype: VolumeMigrationOperationParameters
        """
        return self._volume_migration

    @volume_migration.setter
    def volume_migration(self, volume_migration):
        """Sets the volume_migration of this JobOperationParameters.


        :param volume_migration: The volume_migration of this JobOperationParameters.  # noqa: E501
        :type: VolumeMigrationOperationParameters
        """

        self._volume_migration = volume_migration

    @property
    def file_copy(self):
        """Gets the file_copy of this JobOperationParameters.  # noqa: E501


        :return: The file_copy of this JobOperationParameters.  # noqa: E501
        :rtype: FileCopyOperationParameters
        """
        return self._file_copy

    @file_copy.setter
    def file_copy(self, file_copy):
        """Sets the file_copy of this JobOperationParameters.


        :param file_copy: The file_copy of this JobOperationParameters.  # noqa: E501
        :type: FileCopyOperationParameters
        """

        self._file_copy = file_copy

    @property
    def bulk_metadata_update(self):
        """Gets the bulk_metadata_update of this JobOperationParameters.  # noqa: E501


        :return: The bulk_metadata_update of this JobOperationParameters.  # noqa: E501
        :rtype: BulkMetadataUpdateOperationParameters
        """
        return self._bulk_metadata_update

    @bulk_metadata_update.setter
    def bulk_metadata_update(self, bulk_metadata_update):
        """Sets the bulk_metadata_update of this JobOperationParameters.


        :param bulk_metadata_update: The bulk_metadata_update of this JobOperationParameters.  # noqa: E501
        :type: BulkMetadataUpdateOperationParameters
        """

        self._bulk_metadata_update = bulk_metadata_update

    @property
    def file_move(self):
        """Gets the file_move of this JobOperationParameters.  # noqa: E501


        :return: The file_move of this JobOperationParameters.  # noqa: E501
        :rtype: FileMoveOperationParameters
        """
        return self._file_move

    @file_move.setter
    def file_move(self, file_move):
        """Sets the file_move of this JobOperationParameters.


        :param file_move: The file_move of this JobOperationParameters.  # noqa: E501
        :type: FileMoveOperationParameters
        """

        self._file_move = file_move

    @property
    def folder_move(self):
        """Gets the folder_move of this JobOperationParameters.  # noqa: E501


        :return: The folder_move of this JobOperationParameters.  # noqa: E501
        :rtype: FolderMoveOperationParameters
        """
        return self._folder_move

    @folder_move.setter
    def folder_move(self, folder_move):
        """Sets the folder_move of this JobOperationParameters.


        :param folder_move: The folder_move of this JobOperationParameters.  # noqa: E501
        :type: FolderMoveOperationParameters
        """

        self._folder_move = folder_move

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobOperationParameters):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JobOperationParameters):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class JobResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'parent_folder_urn': 'str',
        'operation_type': 'JobOperationType',
        'job_type': 'str',
        'operation_parameters': 'JobOperationParameters',
        'results': 'JobOutput',
        'progress_status': 'JobProgressStatus',
        'time_created': 'datetime',
        'created_by': 'str',
        'time_modified': 'datetime',
        'time_completed': 'datetime',
        'error_message': 'str'
    }

    attribute_map = {
        'id': 'id',
        'parent_folder_urn': 'parentFolderUrn',
        'operation_type': 'operationType',
        'job_type': 'jobType',
        'operation_parameters': 'operationParameters',
        'results': 'results',
        'progress_status': 'progressStatus',
        'time_created': 'timeCreated',
        'created_by': 'createdBy',
        'time_modified': 'timeModified',
        'time_completed': 'timeCompleted',
        'error_message': 'errorMessage'
    }

    def __init__(self, id=None, parent_folder_urn=None, operation_type=None, job_type=None, operation_parameters=None, results=None, progress_status=None, time_created=None, created_by=None, time_modified=None, time_completed=None, error_message=None, local_vars_configuration=None):  # noqa: E501
        """JobResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._parent_folder_urn = None
        self._operation_type = None
        self._job_type = None
        self._operation_parameters = None
        self._results = None
        self._progress_status = None
        self._time_created = None
        self._created_by = None
        self._time_modified = None
        self._time_completed = None
        self._error_message = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if parent_folder_urn is not None:
            self.parent_folder_urn = parent_folder_urn
        if operation_type is not None:
            self.operation_type = operation_type
        if job_type is not None:
            self.job_type = job_type
        if operation_parameters is not None:
            self.operation_parameters = operation_parameters
        if results is not None:
            self.results = results
        if progress_status is not None:
            self.progress_status = progress_status
        if time_created is not None:
            self.time_created = time_created
        if created_by is not None:
            self.created_by = created_by
        if time_modified is not None:
            self.time_modified = time_modified
        if time_completed is not None:
            self.time_completed = time_completed
        if error_message is not None:
            self.error_message = error_message

    @property
    def id(self):
        """Gets the id of this JobResponse.  # noqa: E501

        A unique identifier for this Job  # noqa: E501

        :return: The id of this JobResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this JobResponse.

        A unique identifier for this Job  # noqa: E501

        :param id: The id of this JobResponse.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def parent_folder_urn(self):
        """Gets the parent_folder_urn of this JobResponse.  # noqa: E501

        The Universal Resource Name of the parent folder associated with the Job  # noqa: E501

        :return: The parent_folder_urn of this JobResponse.  # noqa: E501
        :rtype: str
        """
        return self._parent_folder_urn

    @parent_folder_urn.setter
    def parent_folder_urn(self, parent_folder_urn):
        """Sets the parent_folder_urn of this JobResponse.

        The Universal Resource Name of the parent folder associated with the Job  # noqa: E501

        :param parent_folder_urn: The parent_folder_urn of this JobResponse.  # noqa: E501
        :type: str
        """

        self._parent_folder_urn = parent_folder_urn

    @property
    def operation_type(self):
        """Gets the operation_type of this JobResponse.  # noqa: E501


        :return: The operation_type of this JobResponse.  # noqa: E501
        :rtype: JobOperationType
        """
        return self._operation_type

    @operation_type.setter
    def operation_type(self, operation_type):
        """Sets the operation_type of this JobResponse.


        :param operation_type: The operation_type of this JobResponse.  # noqa: E501
        :type: JobOperationType
        """

        self._operation_type = operation_type

    @property
    def job_type(self):
        """Gets the job_type of this JobResponse.  # noqa: E501


        :return: The job_type of this JobResponse.  # noqa: E501
        :rtype: str
        """
        return self._job_type

    @job_type.setter
    def job_type(self, job_type):
        """Sets the job_type of this JobResponse.


        :param job_type: The job_type of this JobResponse.  # noqa: E501
        :type: str
        """

        self._job_type = job_type

    @property
    def operation_parameters(self):
        """Gets the operation_parameters of this JobResponse.  # noqa: E501


        :return: The operation_parameters of this JobResponse.  # noqa: E501
        :rtype: JobOperationParameters
        """
        return self._operation_parameters

    @operation_parameters.setter
    def operation_parameters(self, operation_parameters):
        """Sets the operation_parameters of this JobResponse.


        :param operation_parameters: The operation_parameters of this JobResponse.  # noqa: E501
        :type: JobOperationParameters
        """

        self._operation_parameters = operation_parameters

    @property
    def results(self):
        """Gets the results of this JobResponse.  # noqa: E501


        :return: The results of this JobResponse.  # noqa: E501
        :rtype: JobOutput
        """
        return self._results

    @results.setter
    def results(self, results):
        """Sets the results of this JobResponse.


        :param results: The results of this JobResponse.  # noqa: E501
        :type: JobOutput
        """

        self._results = results

    @property
    def progress_status(self):
        """Gets the progress_status of this JobResponse.  # noqa: E501


        :return: The progress_status of this JobResponse.  # noqa: E501
        :rtype: JobProgressStatus
        """
        return self._progress_status

    @progress_status.setter
    def progress_status(self, progress_status):
        """Sets the progress_status of this JobResponse.


        :param progress_status: The progress_status of this JobResponse.  # noqa: E501
        :type: JobProgressStatus
        """

        self._progress_status = progress_status

    @property
    def time_created(self):
        """Gets the time_created of this JobResponse.  # noqa: E501

        The date & time this Folder was created, in GDS  # noqa: E501

        :return: The time_created of this JobResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """Sets the time_created of this JobResponse.

        The date & time this Folder was created, in GDS  # noqa: E501

        :param time_created: The time_created of this JobResponse.  # noqa: E501
        :type: datetime
        """

        self._time_created = time_created

    @property
    def created_by(self):
        """Gets the created_by of this JobResponse.  # noqa: E501

        The creator of this Job  # noqa: E501

        :return: The created_by of this JobResponse.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this JobResponse.

        The creator of this Job  # noqa: E501

        :param created_by: The created_by of this JobResponse.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def time_modified(self):
        """Gets the time_modified of this JobResponse.  # noqa: E501

        The date & time this Job was updated, in GDS  # noqa: E501

        :return: The time_modified of this JobResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_modified

    @time_modified.setter
    def time_modified(self, time_modified):
        """Sets the time_modified of this JobResponse.

        The date & time this Job was updated, in GDS  # noqa: E501

        :param time_modified: The time_modified of this JobResponse.  # noqa: E501
        :type: datetime
        """

        self._time_modified = time_modified

    @property
    def time_completed(self):
        """Gets the time_completed of this JobResponse.  # noqa: E501

        The date & time this Job was completed, in GDS  # noqa: E501

        :return: The time_completed of this JobResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_completed

    @time_completed.setter
    def time_completed(self, time_completed):
        """Sets the time_completed of this JobResponse.

        The date & time this Job was completed, in GDS  # noqa: E501

        :param time_completed: The time_completed of this JobResponse.  # noqa: E501
        :type: datetime
        """

        self._time_completed = time_completed

    @property
    def error_message(self):
        """Gets the error_message of this JobResponse.  # noqa: E501

        Error message returned from the job  # noqa: E501

        :return: The error_message of this JobResponse.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this JobResponse.

        Error message returned from the job  # noqa: E501

        :param error_message: The error_message of this JobResponse.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JobResponse):
            return True

        return self.to_dict() != other.to_dict()



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="libica",
    version="2.4.0rc1",
    url="https://github.com/umccr-illumina/libica",
    license="MIT",
    author="UMCCR and Contributors",
    author_email="services@umccr.org",
    description="Python SDK for Illumina Connected Analytics",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages(exclude=("tests**", "**test**", "docs")),
    project_urls={
        "Bug Tracker": "https://github.com/umccr-illumina/libica/issues",
    },
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.7",
    extras_require={
        "dev": [
            "pipdeptree",
            "twine",
            "setuptools",
            "wheel",
            "build",
            "pdoc3",
            "mkdocs",
            "mkdocs-material",
            "openapi-spec-validator",
            "pre-commit",
            "detect-secrets",
            "black",
            "ggshield"
        ],
        "test": [
            "pytest",
            "pytest-cov",
            "flake8",
            "mockito",
            "tox",
            "nose2",
        ],
    },
    install_requires=[
        "requests",
        "python-dateutil",
        "six",
        "urllib3",
        "certifi",
        "libumccr",
        "PyYAML",
        "boto3",
        "botocore",
    ],
)



# coding: utf-8

# flake8: noqa

"""
    Workflow Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from libica.openapi.libwes.api.workflow_runs_api import WorkflowRunsApi
from libica.openapi.libwes.api.workflow_signals_api import WorkflowSignalsApi
from libica.openapi.libwes.api.workflow_versions_api import WorkflowVersionsApi
from libica.openapi.libwes.api.workflows_api import WorkflowsApi

# import ApiClient
from libica.openapi.libwes.api_client import ApiClient
from libica.openapi.libwes.configuration import Configuration
from libica.openapi.libwes.exceptions import OpenApiException
from libica.openapi.libwes.exceptions import ApiTypeError
from libica.openapi.libwes.exceptions import ApiValueError
from libica.openapi.libwes.exceptions import ApiKeyError
from libica.openapi.libwes.exceptions import ApiException
# import models into sdk package
from libica.openapi.libwes.models.abort_workflow_run_request import AbortWorkflowRunRequest
from libica.openapi.libwes.models.create_workflow_request import CreateWorkflowRequest
from libica.openapi.libwes.models.create_workflow_version_request import CreateWorkflowVersionRequest
from libica.openapi.libwes.models.error_response import ErrorResponse
from libica.openapi.libwes.models.fail_workflow_signal_request import FailWorkflowSignalRequest
from libica.openapi.libwes.models.launch_workflow_version_request import LaunchWorkflowVersionRequest
from libica.openapi.libwes.models.succeed_workflow_signal_request import SucceedWorkflowSignalRequest
from libica.openapi.libwes.models.update_workflow_request import UpdateWorkflowRequest
from libica.openapi.libwes.models.update_workflow_version_request import UpdateWorkflowVersionRequest
from libica.openapi.libwes.models.workflow import Workflow
from libica.openapi.libwes.models.workflow_argument import WorkflowArgument
from libica.openapi.libwes.models.workflow_compact import WorkflowCompact
from libica.openapi.libwes.models.workflow_connection import WorkflowConnection
from libica.openapi.libwes.models.workflow_language import WorkflowLanguage
from libica.openapi.libwes.models.workflow_list import WorkflowList
from libica.openapi.libwes.models.workflow_run import WorkflowRun
from libica.openapi.libwes.models.workflow_run_compact import WorkflowRunCompact
from libica.openapi.libwes.models.workflow_run_history_event import WorkflowRunHistoryEvent
from libica.openapi.libwes.models.workflow_run_history_event_list import WorkflowRunHistoryEventList
from libica.openapi.libwes.models.workflow_run_list import WorkflowRunList
from libica.openapi.libwes.models.workflow_signal import WorkflowSignal
from libica.openapi.libwes.models.workflow_signal_compact import WorkflowSignalCompact
from libica.openapi.libwes.models.workflow_signal_list import WorkflowSignalList
from libica.openapi.libwes.models.workflow_version import WorkflowVersion
from libica.openapi.libwes.models.workflow_version_compact import WorkflowVersionCompact
from libica.openapi.libwes.models.workflow_version_list import WorkflowVersionList




# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class AwsS3PresignedUrlForUpload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'single_part_url': 'str',
        'multipart_template': 'str',
        'multipart_signatures': 'list[PartInfo]',
        'multipart_upload_id': 'str',
        'server_side_encryption_algorithm': 'str',
        'server_side_encryption_key': 'str'
    }

    attribute_map = {
        'single_part_url': 'singlePartUrl',
        'multipart_template': 'multipartTemplate',
        'multipart_signatures': 'multipartSignatures',
        'multipart_upload_id': 'multipartUploadId',
        'server_side_encryption_algorithm': 'serverSideEncryptionAlgorithm',
        'server_side_encryption_key': 'serverSideEncryptionKey'
    }

    def __init__(self, single_part_url=None, multipart_template=None, multipart_signatures=None, multipart_upload_id=None, server_side_encryption_algorithm=None, server_side_encryption_key=None, local_vars_configuration=None):  # noqa: E501
        """AwsS3PresignedUrlForUpload - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._single_part_url = None
        self._multipart_template = None
        self._multipart_signatures = None
        self._multipart_upload_id = None
        self._server_side_encryption_algorithm = None
        self._server_side_encryption_key = None
        self.discriminator = None

        if single_part_url is not None:
            self.single_part_url = single_part_url
        if multipart_template is not None:
            self.multipart_template = multipart_template
        if multipart_signatures is not None:
            self.multipart_signatures = multipart_signatures
        if multipart_upload_id is not None:
            self.multipart_upload_id = multipart_upload_id
        if server_side_encryption_algorithm is not None:
            self.server_side_encryption_algorithm = server_side_encryption_algorithm
        if server_side_encryption_key is not None:
            self.server_side_encryption_key = server_side_encryption_key

    @property
    def single_part_url(self):
        """Gets the single_part_url of this AwsS3PresignedUrlForUpload.  # noqa: E501

        A single part presigned url for upload  # noqa: E501

        :return: The single_part_url of this AwsS3PresignedUrlForUpload.  # noqa: E501
        :rtype: str
        """
        return self._single_part_url

    @single_part_url.setter
    def single_part_url(self, single_part_url):
        """Sets the single_part_url of this AwsS3PresignedUrlForUpload.

        A single part presigned url for upload  # noqa: E501

        :param single_part_url: The single_part_url of this AwsS3PresignedUrlForUpload.  # noqa: E501
        :type: str
        """

        self._single_part_url = single_part_url

    @property
    def multipart_template(self):
        """Gets the multipart_template of this AwsS3PresignedUrlForUpload.  # noqa: E501

        A url template for multi parts presigned url for upload  # noqa: E501

        :return: The multipart_template of this AwsS3PresignedUrlForUpload.  # noqa: E501
        :rtype: str
        """
        return self._multipart_template

    @multipart_template.setter
    def multipart_template(self, multipart_template):
        """Sets the multipart_template of this AwsS3PresignedUrlForUpload.

        A url template for multi parts presigned url for upload  # noqa: E501

        :param multipart_template: The multipart_template of this AwsS3PresignedUrlForUpload.  # noqa: E501
        :type: str
        """

        self._multipart_template = multipart_template

    @property
    def multipart_signatures(self):
        """Gets the multipart_signatures of this AwsS3PresignedUrlForUpload.  # noqa: E501

        Multi parts info that needs to be applied to the MultipartTemplate  # noqa: E501

        :return: The multipart_signatures of this AwsS3PresignedUrlForUpload.  # noqa: E501
        :rtype: list[PartInfo]
        """
        return self._multipart_signatures

    @multipart_signatures.setter
    def multipart_signatures(self, multipart_signatures):
        """Sets the multipart_signatures of this AwsS3PresignedUrlForUpload.

        Multi parts info that needs to be applied to the MultipartTemplate  # noqa: E501

        :param multipart_signatures: The multipart_signatures of this AwsS3PresignedUrlForUpload.  # noqa: E501
        :type: list[PartInfo]
        """

        self._multipart_signatures = multipart_signatures

    @property
    def multipart_upload_id(self):
        """Gets the multipart_upload_id of this AwsS3PresignedUrlForUpload.  # noqa: E501

        Multi part upload id  # noqa: E501

        :return: The multipart_upload_id of this AwsS3PresignedUrlForUpload.  # noqa: E501
        :rtype: str
        """
        return self._multipart_upload_id

    @multipart_upload_id.setter
    def multipart_upload_id(self, multipart_upload_id):
        """Sets the multipart_upload_id of this AwsS3PresignedUrlForUpload.

        Multi part upload id  # noqa: E501

        :param multipart_upload_id: The multipart_upload_id of this AwsS3PresignedUrlForUpload.  # noqa: E501
        :type: str
        """

        self._multipart_upload_id = multipart_upload_id

    @property
    def server_side_encryption_algorithm(self):
        """Gets the server_side_encryption_algorithm of this AwsS3PresignedUrlForUpload.  # noqa: E501

        The server side encryption method used by S3.  This value is used to determine the Amazon S3 header \"x-amz-server-side-encryption\" value.  Possible values: 'AES256' and 'aws:kms'.  # noqa: E501

        :return: The server_side_encryption_algorithm of this AwsS3PresignedUrlForUpload.  # noqa: E501
        :rtype: str
        """
        return self._server_side_encryption_algorithm

    @server_side_encryption_algorithm.setter
    def server_side_encryption_algorithm(self, server_side_encryption_algorithm):
        """Sets the server_side_encryption_algorithm of this AwsS3PresignedUrlForUpload.

        The server side encryption method used by S3.  This value is used to determine the Amazon S3 header \"x-amz-server-side-encryption\" value.  Possible values: 'AES256' and 'aws:kms'.  # noqa: E501

        :param server_side_encryption_algorithm: The server_side_encryption_algorithm of this AwsS3PresignedUrlForUpload.  # noqa: E501
        :type: str
        """

        self._server_side_encryption_algorithm = server_side_encryption_algorithm

    @property
    def server_side_encryption_key(self):
        """Gets the server_side_encryption_key of this AwsS3PresignedUrlForUpload.  # noqa: E501

        Server-side encryption key that might be associated with the specified server-side encryption algorithm  This value can be the AWS KMS arn key, to be used for the Amazon S3 header \"x-amz-server-side-encryption-aws-kms-key-id\" value  This is only used when ServerSideEncryptionAlgorithm is 'aws:kms'  # noqa: E501

        :return: The server_side_encryption_key of this AwsS3PresignedUrlForUpload.  # noqa: E501
        :rtype: str
        """
        return self._server_side_encryption_key

    @server_side_encryption_key.setter
    def server_side_encryption_key(self, server_side_encryption_key):
        """Sets the server_side_encryption_key of this AwsS3PresignedUrlForUpload.

        Server-side encryption key that might be associated with the specified server-side encryption algorithm  This value can be the AWS KMS arn key, to be used for the Amazon S3 header \"x-amz-server-side-encryption-aws-kms-key-id\" value  This is only used when ServerSideEncryptionAlgorithm is 'aws:kms'  # noqa: E501

        :param server_side_encryption_key: The server_side_encryption_key of this AwsS3PresignedUrlForUpload.  # noqa: E501
        :type: str
        """

        self._server_side_encryption_key = server_side_encryption_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AwsS3PresignedUrlForUpload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AwsS3PresignedUrlForUpload):
            return True

        return self.to_dict() != other.to_dict()



# -*- coding: utf-8 -*-
"""app package

ImplNote:
Consider implementation here should be reusable application needs for common use cases.
Consider not to re-do openapi generality.
"""
import copy
import logging
import os
from enum import Enum
from os.path import expanduser

import yaml
from libumccr.aws import libsm

logger = logging.getLogger(__name__)

# v1
ICA_BASE_URL = "https://aps2.platform.illumina.com"
ICA_TOKEN_SECRET_NAME = "IcaSecretsPortal"  # pragma: allowlist secret

# v2
ICA_URL = "https://ica.illumina.com/ica/rest"
ICAV2_TOKEN_SECRET_NAME = "Icav2SecretsPortal"  # pragma: allowlist secret
ICAV2_API_KEY_SECRET_NAME = "Icav2ApiKeySecretsPortal"  # pragma: allowlist secret


class ENSEventType(Enum):
    """
    REF:
    https://support-docs.illumina.com/SW/ICA/Content/SW/ICA/ENS_AvailableEvents.htm
    """
    GDS_FILES = "gds.files"
    BSSH_RUNS = "bssh.runs"
    WES_RUNS = "wes.runs"


class GDSFilesEventType(Enum):
    """
    REF:
    https://support-docs.illumina.com/SW/ICA/Content/SW/ICA/ENS_AvailableEvents.htm
    """
    UPLOADED = "uploaded"
    DELETED = "deleted"
    ARCHIVED = "archived"
    UNARCHIVED = "unarchived"

    @classmethod
    def from_value(cls, value):
        if value == cls.UPLOADED.value:
            return cls.UPLOADED
        elif value == cls.DELETED.value:
            return cls.DELETED
        elif value == cls.ARCHIVED.value:
            return cls.ARCHIVED
        elif value == cls.UNARCHIVED.value:
            return cls.UNARCHIVED
        else:
            raise ValueError(f"No matching enum found for value: {value}")


def configuration(lib, secret_name=None, base_url=None, debug=False):
    ica_access_token = os.getenv("ICA_ACCESS_TOKEN", None)
    if ica_access_token is None and secret_name:
        ica_access_token = libsm.get_secret(secret_name=secret_name)
    elif ica_access_token is None:
        ica_access_token = libsm.get_secret(secret_name=ICA_TOKEN_SECRET_NAME)

    ica_base_url = os.getenv("ICA_BASE_URL", None)
    if ica_base_url is None and base_url:
        ica_base_url = base_url
    elif ica_base_url is None:
        ica_base_url = ICA_BASE_URL

    config = lib.Configuration(
        host=ica_base_url,
        api_key={
            'Authorization': ica_access_token
        },
        api_key_prefix={
            'Authorization': "Bearer"
        },
    )

    # WARNING:
    # it print stdout all libica.openapi http calls activity including JWT token in http header
    config.debug = debug

    return config


class ProjectDataType(Enum):
    FILE = "FILE"
    FOLDER = "FOLDER"

    @classmethod
    def from_value(cls, value):
        if str(value).lower() == str(cls.FILE.value).lower():
            return cls.FILE
        elif str(value).lower() == str(cls.FOLDER.value).lower():
            return cls.FOLDER
        else:
            raise ValueError(f"No matching enum found for value: {value}")


class AppHelper:

    def __init__(self, secret_name=None, ica_url=None, debug=False):
        self.session_file = expanduser("~/.icav2/.session.ica.yaml")
        self.secret_name = secret_name
        self.ica_url = ica_url
        self.debug = debug
        self.configuration = None

    def get_icav2_cli_session_file(self):
        return self.session_file

    def get_configuration(self):
        return self.configuration

    def get_icav2_cli_session(self) -> dict:
        with open(self.session_file, 'r') as f:
            session = yaml.safe_load(f)
            session['access_token'] = session.pop('access-token') if 'access-token' in session.keys() else None
            session['project_id'] = session.pop('project-id') if 'project-id' in session.keys() else None
            return copy.deepcopy(session)

    def get_icav2_cli_session_project_id(self):
        session = self.get_icav2_cli_session()
        project_id = os.getenv("ICAV2_PROJECT_ID", session['project_id'])
        return project_id

    def build_icav2_configuration(self):
        from libica.openapi.v2 import Configuration

        _icav2_access_token = os.getenv("ICAV2_ACCESS_TOKEN", None)
        if _icav2_access_token is None and self.secret_name:
            _icav2_access_token = libsm.get_secret(secret_name=self.secret_name)
        elif _icav2_access_token is None:
            _icav2_access_token = libsm.get_secret(secret_name=ICAV2_TOKEN_SECRET_NAME)

        _ica_url = os.getenv("ICA_URL", None)
        if _ica_url is None and self.ica_url:
            _ica_url = self.ica_url
        elif _ica_url is None:
            _ica_url = ICA_URL

        self.configuration = Configuration(
            host=_ica_url,
            access_token=_icav2_access_token,
        )

        self.configuration.debug = self.debug

        return self

    def build_icav2_configuration_with_cli_session(self):
        from libica.openapi.v2 import Configuration

        _icav2_access_token = os.getenv("ICAV2_ACCESS_TOKEN", self.get_icav2_cli_session()['access_token'])
        if _icav2_access_token is None and self.secret_name:
            _icav2_access_token = libsm.get_secret(secret_name=self.secret_name)
        elif _icav2_access_token is None:
            _icav2_access_token = libsm.get_secret(secret_name=ICAV2_TOKEN_SECRET_NAME)

        _ica_url = os.getenv("ICA_URL", None)
        if _ica_url is None and self.ica_url:
            _ica_url = self.ica_url
        elif _ica_url is None:
            _ica_url = ICA_URL

        self.configuration = Configuration(
            host=_ica_url,
            access_token=_icav2_access_token,
        )

        self.configuration.debug = self.debug

        return self

    def build_icav2_configuration_with_api_key(self, bearer=False):
        from libica.openapi.v2 import Configuration

        _icav2_api_key = os.getenv("ICAV2_API_KEY", None)
        if _icav2_api_key is None and self.secret_name:
            _icav2_api_key = libsm.get_secret(secret_name=self.secret_name)
        elif _icav2_api_key is None:
            _icav2_api_key = libsm.get_secret(secret_name=ICAV2_API_KEY_SECRET_NAME)

        _ica_url = os.getenv("ICA_URL", None)
        if _ica_url is None and self.ica_url:
            _ica_url = self.ica_url
        elif _ica_url is None:
            _ica_url = ICA_URL

        self.configuration = Configuration(
            host=_ica_url,
            api_key={
                'ApiKeyAuth': _icav2_api_key,
            },
        )

        if bearer:
            self.configuration.api_key_prefix['ApiKeyAuth'] = "Bearer"  # pragma: allowlist secret

        self.configuration.debug = self.debug

        return self

    def get_icav2_api_client(self):
        from libica.openapi.v2 import ApiClient
        return ApiClient(
            configuration=self.configuration,
            header_name="Content-Type",
            header_value="application/vnd.illumina.v3+json",
        )


class AppOps:

    def __init__(self, api_client=None):
        if api_client:
            self.api_client = api_client
        else:
            # otherwise, we build api_client with standard lookup from well-known locations
            from libica.openapi.v2 import ApiClient
            self.api_client: ApiClient = AppHelper().build_icav2_configuration().get_icav2_api_client()



# coding: utf-8

"""
    Workflow Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libwes.configuration import Configuration


class CreateWorkflowVersionRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'version': 'str',
        'description': 'str',
        'language': 'WorkflowLanguage',
        'definition': 'object',
        'acl': 'list[str]',
        'status': 'str'
    }

    attribute_map = {
        'version': 'version',
        'description': 'description',
        'language': 'language',
        'definition': 'definition',
        'acl': 'acl',
        'status': 'status'
    }

    def __init__(self, version=None, description=None, language=None, definition=None, acl=None, status=None, local_vars_configuration=None):  # noqa: E501
        """CreateWorkflowVersionRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._version = None
        self._description = None
        self._language = None
        self._definition = None
        self._acl = None
        self._status = None
        self.discriminator = None

        self.version = version
        if description is not None:
            self.description = description
        if language is not None:
            self.language = language
        if definition is not None:
            self.definition = definition
        if acl is not None:
            self.acl = acl
        if status is not None:
            self.status = status

    @property
    def version(self):
        """Gets the version of this CreateWorkflowVersionRequest.  # noqa: E501


        :return: The version of this CreateWorkflowVersionRequest.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this CreateWorkflowVersionRequest.


        :param version: The version of this CreateWorkflowVersionRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and version is None:  # noqa: E501
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                version is not None and len(version) < 1):
            raise ValueError("Invalid value for `version`, length must be greater than or equal to `1`")  # noqa: E501

        self._version = version

    @property
    def description(self):
        """Gets the description of this CreateWorkflowVersionRequest.  # noqa: E501


        :return: The description of this CreateWorkflowVersionRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateWorkflowVersionRequest.


        :param description: The description of this CreateWorkflowVersionRequest.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 256):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) < 0):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `0`")  # noqa: E501

        self._description = description

    @property
    def language(self):
        """Gets the language of this CreateWorkflowVersionRequest.  # noqa: E501


        :return: The language of this CreateWorkflowVersionRequest.  # noqa: E501
        :rtype: WorkflowLanguage
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this CreateWorkflowVersionRequest.


        :param language: The language of this CreateWorkflowVersionRequest.  # noqa: E501
        :type: WorkflowLanguage
        """

        self._language = language

    @property
    def definition(self):
        """Gets the definition of this CreateWorkflowVersionRequest.  # noqa: E501


        :return: The definition of this CreateWorkflowVersionRequest.  # noqa: E501
        :rtype: object
        """
        return self._definition

    @definition.setter
    def definition(self, definition):
        """Sets the definition of this CreateWorkflowVersionRequest.


        :param definition: The definition of this CreateWorkflowVersionRequest.  # noqa: E501
        :type: object
        """

        self._definition = definition

    @property
    def acl(self):
        """Gets the acl of this CreateWorkflowVersionRequest.  # noqa: E501


        :return: The acl of this CreateWorkflowVersionRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._acl

    @acl.setter
    def acl(self, acl):
        """Sets the acl of this CreateWorkflowVersionRequest.


        :param acl: The acl of this CreateWorkflowVersionRequest.  # noqa: E501
        :type: list[str]
        """

        self._acl = acl

    @property
    def status(self):
        """Gets the status of this CreateWorkflowVersionRequest.  # noqa: E501

        Published Status of the workflow version  # noqa: E501

        :return: The status of this CreateWorkflowVersionRequest.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CreateWorkflowVersionRequest.

        Published Status of the workflow version  # noqa: E501

        :param status: The status of this CreateWorkflowVersionRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["draft", "released", "obsolete"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateWorkflowVersionRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateWorkflowVersionRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class VolumeConfigurationResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'storage_container_versioning_state': 'StorageContainerVersioningState',
        'tenant_id': 'str',
        'sub_tenant_id': 'str',
        'urn': 'str',
        'online_status': 'VolumeConfigurationOnlineStatus',
        'error_code': 'str',
        'error_message': 'str',
        'time_of_last_error': 'datetime',
        'time_created': 'datetime',
        'created_by': 'str',
        'time_modified': 'datetime',
        'modified_by': 'str',
        'provider_name': 'ObjectStorageProviderNames',
        'object_store_settings': 'ObjectStoreSettings',
        'restore_type': 'RestoreType'
    }

    attribute_map = {
        'name': 'name',
        'storage_container_versioning_state': 'storageContainerVersioningState',
        'tenant_id': 'tenantId',
        'sub_tenant_id': 'subTenantId',
        'urn': 'urn',
        'online_status': 'onlineStatus',
        'error_code': 'errorCode',
        'error_message': 'errorMessage',
        'time_of_last_error': 'timeOfLastError',
        'time_created': 'timeCreated',
        'created_by': 'createdBy',
        'time_modified': 'timeModified',
        'modified_by': 'modifiedBy',
        'provider_name': 'providerName',
        'object_store_settings': 'objectStoreSettings',
        'restore_type': 'restoreType'
    }

    def __init__(self, name=None, storage_container_versioning_state=None, tenant_id=None, sub_tenant_id=None, urn=None, online_status=None, error_code=None, error_message=None, time_of_last_error=None, time_created=None, created_by=None, time_modified=None, modified_by=None, provider_name=None, object_store_settings=None, restore_type=None, local_vars_configuration=None):  # noqa: E501
        """VolumeConfigurationResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._storage_container_versioning_state = None
        self._tenant_id = None
        self._sub_tenant_id = None
        self._urn = None
        self._online_status = None
        self._error_code = None
        self._error_message = None
        self._time_of_last_error = None
        self._time_created = None
        self._created_by = None
        self._time_modified = None
        self._modified_by = None
        self._provider_name = None
        self._object_store_settings = None
        self._restore_type = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if storage_container_versioning_state is not None:
            self.storage_container_versioning_state = storage_container_versioning_state
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if sub_tenant_id is not None:
            self.sub_tenant_id = sub_tenant_id
        if urn is not None:
            self.urn = urn
        if online_status is not None:
            self.online_status = online_status
        if error_code is not None:
            self.error_code = error_code
        if error_message is not None:
            self.error_message = error_message
        if time_of_last_error is not None:
            self.time_of_last_error = time_of_last_error
        if time_created is not None:
            self.time_created = time_created
        if created_by is not None:
            self.created_by = created_by
        if time_modified is not None:
            self.time_modified = time_modified
        if modified_by is not None:
            self.modified_by = modified_by
        if provider_name is not None:
            self.provider_name = provider_name
        if object_store_settings is not None:
            self.object_store_settings = object_store_settings
        if restore_type is not None:
            self.restore_type = restore_type

    @property
    def name(self):
        """Gets the name of this VolumeConfigurationResponse.  # noqa: E501

        Name for the volume configuration  # noqa: E501

        :return: The name of this VolumeConfigurationResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this VolumeConfigurationResponse.

        Name for the volume configuration  # noqa: E501

        :param name: The name of this VolumeConfigurationResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def storage_container_versioning_state(self):
        """Gets the storage_container_versioning_state of this VolumeConfigurationResponse.  # noqa: E501


        :return: The storage_container_versioning_state of this VolumeConfigurationResponse.  # noqa: E501
        :rtype: StorageContainerVersioningState
        """
        return self._storage_container_versioning_state

    @storage_container_versioning_state.setter
    def storage_container_versioning_state(self, storage_container_versioning_state):
        """Sets the storage_container_versioning_state of this VolumeConfigurationResponse.


        :param storage_container_versioning_state: The storage_container_versioning_state of this VolumeConfigurationResponse.  # noqa: E501
        :type: StorageContainerVersioningState
        """

        self._storage_container_versioning_state = storage_container_versioning_state

    @property
    def tenant_id(self):
        """Gets the tenant_id of this VolumeConfigurationResponse.  # noqa: E501

        The unique identifier for this Volume Configuration's Tenant  # noqa: E501

        :return: The tenant_id of this VolumeConfigurationResponse.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this VolumeConfigurationResponse.

        The unique identifier for this Volume Configuration's Tenant  # noqa: E501

        :param tenant_id: The tenant_id of this VolumeConfigurationResponse.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def sub_tenant_id(self):
        """Gets the sub_tenant_id of this VolumeConfigurationResponse.  # noqa: E501

        The unique identifier for this Volume Configurations's Sub Tenant  # noqa: E501

        :return: The sub_tenant_id of this VolumeConfigurationResponse.  # noqa: E501
        :rtype: str
        """
        return self._sub_tenant_id

    @sub_tenant_id.setter
    def sub_tenant_id(self, sub_tenant_id):
        """Sets the sub_tenant_id of this VolumeConfigurationResponse.

        The unique identifier for this Volume Configurations's Sub Tenant  # noqa: E501

        :param sub_tenant_id: The sub_tenant_id of this VolumeConfigurationResponse.  # noqa: E501
        :type: str
        """

        self._sub_tenant_id = sub_tenant_id

    @property
    def urn(self):
        """Gets the urn of this VolumeConfigurationResponse.  # noqa: E501

        The Universal Resource Name, unique to this Volume Configuration  # noqa: E501

        :return: The urn of this VolumeConfigurationResponse.  # noqa: E501
        :rtype: str
        """
        return self._urn

    @urn.setter
    def urn(self, urn):
        """Sets the urn of this VolumeConfigurationResponse.

        The Universal Resource Name, unique to this Volume Configuration  # noqa: E501

        :param urn: The urn of this VolumeConfigurationResponse.  # noqa: E501
        :type: str
        """

        self._urn = urn

    @property
    def online_status(self):
        """Gets the online_status of this VolumeConfigurationResponse.  # noqa: E501


        :return: The online_status of this VolumeConfigurationResponse.  # noqa: E501
        :rtype: VolumeConfigurationOnlineStatus
        """
        return self._online_status

    @online_status.setter
    def online_status(self, online_status):
        """Sets the online_status of this VolumeConfigurationResponse.


        :param online_status: The online_status of this VolumeConfigurationResponse.  # noqa: E501
        :type: VolumeConfigurationOnlineStatus
        """

        self._online_status = online_status

    @property
    def error_code(self):
        """Gets the error_code of this VolumeConfigurationResponse.  # noqa: E501

        Error code returned from the object store  # noqa: E501

        :return: The error_code of this VolumeConfigurationResponse.  # noqa: E501
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this VolumeConfigurationResponse.

        Error code returned from the object store  # noqa: E501

        :param error_code: The error_code of this VolumeConfigurationResponse.  # noqa: E501
        :type: str
        """

        self._error_code = error_code

    @property
    def error_message(self):
        """Gets the error_message of this VolumeConfigurationResponse.  # noqa: E501

        Error message returned from the object store  # noqa: E501

        :return: The error_message of this VolumeConfigurationResponse.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this VolumeConfigurationResponse.

        Error message returned from the object store  # noqa: E501

        :param error_message: The error_message of this VolumeConfigurationResponse.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def time_of_last_error(self):
        """Gets the time_of_last_error of this VolumeConfigurationResponse.  # noqa: E501

        Timestamp of the last observed error.  # noqa: E501

        :return: The time_of_last_error of this VolumeConfigurationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_of_last_error

    @time_of_last_error.setter
    def time_of_last_error(self, time_of_last_error):
        """Sets the time_of_last_error of this VolumeConfigurationResponse.

        Timestamp of the last observed error.  # noqa: E501

        :param time_of_last_error: The time_of_last_error of this VolumeConfigurationResponse.  # noqa: E501
        :type: datetime
        """

        self._time_of_last_error = time_of_last_error

    @property
    def time_created(self):
        """Gets the time_created of this VolumeConfigurationResponse.  # noqa: E501

        The date & time this Volume was created, in GDS  # noqa: E501

        :return: The time_created of this VolumeConfigurationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """Sets the time_created of this VolumeConfigurationResponse.

        The date & time this Volume was created, in GDS  # noqa: E501

        :param time_created: The time_created of this VolumeConfigurationResponse.  # noqa: E501
        :type: datetime
        """

        self._time_created = time_created

    @property
    def created_by(self):
        """Gets the created_by of this VolumeConfigurationResponse.  # noqa: E501

        The creator of this Volume  # noqa: E501

        :return: The created_by of this VolumeConfigurationResponse.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this VolumeConfigurationResponse.

        The creator of this Volume  # noqa: E501

        :param created_by: The created_by of this VolumeConfigurationResponse.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def time_modified(self):
        """Gets the time_modified of this VolumeConfigurationResponse.  # noqa: E501

        The date & time this Volume was updated, in GDS  # noqa: E501

        :return: The time_modified of this VolumeConfigurationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_modified

    @time_modified.setter
    def time_modified(self, time_modified):
        """Sets the time_modified of this VolumeConfigurationResponse.

        The date & time this Volume was updated, in GDS  # noqa: E501

        :param time_modified: The time_modified of this VolumeConfigurationResponse.  # noqa: E501
        :type: datetime
        """

        self._time_modified = time_modified

    @property
    def modified_by(self):
        """Gets the modified_by of this VolumeConfigurationResponse.  # noqa: E501

        The updator of this Volume  # noqa: E501

        :return: The modified_by of this VolumeConfigurationResponse.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this VolumeConfigurationResponse.

        The updator of this Volume  # noqa: E501

        :param modified_by: The modified_by of this VolumeConfigurationResponse.  # noqa: E501
        :type: str
        """

        self._modified_by = modified_by

    @property
    def provider_name(self):
        """Gets the provider_name of this VolumeConfigurationResponse.  # noqa: E501


        :return: The provider_name of this VolumeConfigurationResponse.  # noqa: E501
        :rtype: ObjectStorageProviderNames
        """
        return self._provider_name

    @provider_name.setter
    def provider_name(self, provider_name):
        """Sets the provider_name of this VolumeConfigurationResponse.


        :param provider_name: The provider_name of this VolumeConfigurationResponse.  # noqa: E501
        :type: ObjectStorageProviderNames
        """

        self._provider_name = provider_name

    @property
    def object_store_settings(self):
        """Gets the object_store_settings of this VolumeConfigurationResponse.  # noqa: E501


        :return: The object_store_settings of this VolumeConfigurationResponse.  # noqa: E501
        :rtype: ObjectStoreSettings
        """
        return self._object_store_settings

    @object_store_settings.setter
    def object_store_settings(self, object_store_settings):
        """Sets the object_store_settings of this VolumeConfigurationResponse.


        :param object_store_settings: The object_store_settings of this VolumeConfigurationResponse.  # noqa: E501
        :type: ObjectStoreSettings
        """

        self._object_store_settings = object_store_settings

    @property
    def restore_type(self):
        """Gets the restore_type of this VolumeConfigurationResponse.  # noqa: E501


        :return: The restore_type of this VolumeConfigurationResponse.  # noqa: E501
        :rtype: RestoreType
        """
        return self._restore_type

    @restore_type.setter
    def restore_type(self, restore_type):
        """Sets the restore_type of this VolumeConfigurationResponse.


        :param restore_type: The restore_type of this VolumeConfigurationResponse.  # noqa: E501
        :type: RestoreType
        """

        self._restore_type = restore_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VolumeConfigurationResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VolumeConfigurationResponse):
            return True

        return self.to_dict() != other.to_dict()
